push_textdomain("texts")
tips = {
   {
      text = _"Keep an eye on your fishers and build a fish breeder’s house. After fish resources are exhausted in their work area, the fish supply cannot be regenerated.",
      seconds = 4
   },
   {
      text = _"Always build a forester’s and a woodcutter’s house, so you will not run out of logs.",
      seconds = 5
   },
   {
      text = _"Atlanteans need spidercloth for many buildings. Build the needed infrastructure early before you run out.",
      seconds = 5
   },
}
pop_textdomain()
return tips
